#
# spec file for package x3270
#
# Copyright (c) 2016,2020,2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _suffix ga12
%define _fullname suite3270-%{version}%{_suffix}
%define _x026ver 1.2
Name:           x3270
Version:        3.6
Release:        lp152.4.3.1
Summary:        A Family of IBM 3270 Terminal Emulators
License:        MIT
Group:          System/X11/Terminals
URL:            http://x3270.bgp.nu
#Git-Clone:     https://github.com/pmattes/x3270
Source0:        http://download.sourceforge.net/%{name}/%{_fullname}-src.tgz
Source1:        http://download.sourceforge.net/%{name}/x026-%{_x026ver}.tgz
Source2:        x3270.desktop
Patch0:         mknod.patch
Patch1:         x3270-handle-missing-font.patch
Patch100:       usr_local_bin.patch
Patch102:       x026-offset.diff
Patch105:       x3270-missing-include.patch
Patch106:       x3270-missing-file.patch
Patch108:       mkversion.patch
Patch109:       reproducible.patch
BuildRequires:  bdftopcf
BuildRequires:  fdupes
BuildRequires:  fontpackages-devel
BuildRequires:  freetype2
BuildRequires:  imake
BuildRequires:  mkfontdir
BuildRequires:  ncurses-devel
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  tcl-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xpm)
BuildRequires:  pkgconfig(xt)

%description
This package contains a family of IBM 3270 mainframe terminal
emulators:

* terminal emulators for interactive use x3270	X Window System
   c3270  curses based

* terminal emulators for scripted use s3270    see the x3270-script
   man page tcl3270  Tcl based

* printer emulator pr3287

* do not miss the punch card puncher emulator x026

x3270 is an IBM 3270 terminal emulator for the X Window System.  x3270
runs over a telnet connection (with or without TN3270E) and emulates
either an IBM 3279 (color) or 3278 (monochrome).  It supports APL2
characters, IND$FILE file transfer, NVT mode, a pop-up keypad for
3270-specific keys, alternative keymaps, 3287 printer sessions, and a
scrollbar and has extensive debugging and scripting facilities.

c3270 is the curses-based version of x3270.  It runs on any dumb
terminal (an xterm or a console, for example), and supports (almost)
all of the x3270 features.  c3270 scripts are compatible with x3270
scripts, and the subset of command line options and resource
definitions are also compatible.

s3270 is a scripting-only version of x3270.  This program is intended
primarily for writing "screen-scraping" applications, for example a CGI
back-end script that retrieves database information from a mainframe.

tcl3270 is a Tcl-based 3270 scripting engine.  It lets you write Tcl
scripts that manipulate 3270 sessions, and is quite a bit easier to set
up and use than s3270.

pr3287 is the printer companion for the above tools, and allows printer
output from a 3270 session to be directed to a Unix printer queue.

x026 is a fun toy which emulates an x026 puncher.

%prep
# the source-packages all extract to corresponding subdirectories.
# they are all expanded below a 'all3270' directory.  this directory
# will also hold the common config.cache
# -q uietly -c reate -name all3270
# -a fter changing into all3270, expand sources
%setup -q -n suite3270-%{version} -a1
%patch0
%patch1
%patch100
%patch102
%patch105 -p1
%patch106 -p1
for d in x3270 c3270 s3270 tcl3270 pr3287 ; do
(cd $d
%patch108 -p2
%patch109 -p2
)
done

%build
export CFLAGS="%{optflags}"
export LIBX3270DIR=%{_sysconfdir}/x3270
%configure \
  --disable-windows \
  --disable-windows-lib \
  --enable-lib \
  --enable-unix \
  --enable-ssl \
  --x-includes=%{_includedir} \
  --x-libraries=%{_libdir} \
  --with-all-xinstall \
  --with-iconv \
  --with-fontdir=%{_miscfontsdir}
# There is broken generated makefile
sed -i -e 's:$(FALLBACKS_:$(FALLBACKS):g' x3270/Makefile
%make_build LIBX3270DIR=${LIBX3270DIR} unix CC="gcc %{optflags}"
# the IBM 026 keypunch emulator
cd x026-%{_x026ver}
    xmkmf
    %make_build
cd ..

%install
export LIBX3270DIR=%{_sysconfdir}/x3270
# create the default directory structure in the build root
mkdir --parents %{buildroot}{%{_bindir},%{_mandir}/{man1,man5}}
chmod -x x3270/html/Keymap.html
chmod -x s3270/Examples/cms_cmd.expect
make DESTDIR=%{buildroot} LIBX3270DIR=${LIBX3270DIR} install
make DESTDIR=%{buildroot} LIBX3270DIR=${LIBX3270DIR} install.man
# the IBM 026 keypunch emulator
cd x026-%{_x026ver}
    make DESTDIR=%{buildroot} install install.man
cd ..
# move site config files to the standard locations
mkdir -p %{buildroot}%{_libexecdir}/x3270
# this is a per-site, not a per-machine config file
chmod 644 %{buildroot}%{_sysconfdir}/x3270/ibm_hosts
# set permissions correct
chmod ugo-x %{buildroot}%{_mandir}/man{1,5}/*
# make install does a mkfontdir, that creates a fonts.dir we don't
# want in the package.  remove that:
rm %{buildroot}%{_miscfontsdir}/fonts.dir

# copy the docs
mkdir -p %{buildroot}%{_docdir}/%{name}
cp -pr --parents Playback %{buildroot}%{_docdir}/%{name}
cp -pr --parents x3270/{Examples,html} %{buildroot}%{_docdir}/%{name}
cp -pr --parents c3270/html %{buildroot}%{_docdir}/%{name}
cp -pr --parents pr3287/html %{buildroot}%{_docdir}/%{name}
cp -pr --parents s3270/{Examples,html} %{buildroot}%{_docdir}/%{name}
cp -pr --parents tcl3270/{Examples,html} %{buildroot}%{_docdir}/%{name}
# create symlinks in documentation
%fdupes -s %{buildroot}/%{_docdir}

install -D -m 0644 %{SOURCE2} %{buildroot}%{_datadir}/applications/x3270.desktop
%suse_update_desktop_file x3270

%post
%desktop_database_post
%reconfigure_fonts_post

%postun
%desktop_database_postun
%reconfigure_fonts_postun

%posttrans
%reconfigure_fonts_posttrans

%files
%defattr(-,root,root,755)
# common files
%dir %{_sysconfdir}/x3270
%dir %{_docdir}/%{name}
%dir %{_docdir}/%{name}/*
%config(noreplace) %{_sysconfdir}/x3270/ibm_hosts
%{_mandir}/man5/ibm_hosts.5%{?ext_man}
%{_mandir}/man1/x3270if.1%{?ext_man}
%{_mandir}/man1/x3270-script.1%{?ext_man}
%{_bindir}/x3270if
# x3270
%{_bindir}/x3270
%dir %{_miscfontsdir}
%{_miscfontsdir}/*
%{_mandir}/man1/x3270.1%{?ext_man}
%doc %{_docdir}/%{name}/x3270/Examples
%doc %{_docdir}/%{name}/x3270/html
%doc %{_docdir}/%{name}/Playback
%{_datadir}/applications/x3270.desktop
# c3270
%{_bindir}/c3270
%{_mandir}/man1/c3270.1%{?ext_man}
%doc %{_docdir}/%{name}/c3270/html
# pr3287
%{_bindir}/pr3287
%{_mandir}/man1/pr3287.1%{?ext_man}
%doc %{_docdir}/%{name}/pr3287/html
# s3270
%{_bindir}/s3270
%{_mandir}/man1/s3270.1%{?ext_man}
%doc %{_docdir}/%{name}/s3270/Examples
%doc %{_docdir}/%{name}/s3270/html
# tcl3270
%{_bindir}/tcl3270
%{_mandir}/man1/tcl3270.1%{?ext_man}
%doc %{_docdir}/%{name}/tcl3270/Examples
%doc %{_docdir}/%{name}/tcl3270/html
# x026
%{_bindir}/x026
%{_mandir}/man1/x026.1x%{ext_man}

%changelog
* Thu Feb 11 2021 Mark Post <mpost@suse.com>
- Added x3270-handle-missing-font.patch (bsc#1177104)
  In some cases when fonts are present locally but are not present
  in the fontpath, x3270 can crash due to a segfault caused by
  XLoadQueryFont() returning NULL in lff_single().
* Mon Nov  9 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to override build date (boo#1047218)
* Fri Apr 17 2020 Andreas Stieger <andreas.stieger@gmx.de>
- x3270 3.r6ga12:
  * Potentially incompatible changes:
    + Removed explicit support for self-signed host certificates.
    + To allow self-signed certificates, disable verification.
    + Switched to verifying host certficates by default. This can
    be disabled by using the -noverifycert opton or by setting
    the verifyHostCert resource to false.
  * Many bug fixes and minor feature additions
- drop reproducible.patch, x3270-fix-build.patch, upstreamed
* Thu Sep  5 2019 Marcus Meissner <meissner@suse.com>
- x3270-fix-build.patch: fixed a bug triggered by LTO, commented
  out incompat definition.
* Sat Jul 14 2018 bwiedemann@suse.com
- Add mkversion.patch to have fixed timestamps (boo#1047218)
- Add reproducible.patch to not add timestamps in .gz header
* Wed Dec 28 2016 mpluskal@suse.com
- Update to ga9 of 3.5 series:
  * [x3270] Fixed the toggle names saved with the File->Save
    Changed Options menu option and when processing the
    WM_SAVE_YOURSELF message.
  * [x3270] Explicitly test for X11, Xt, Xmu and Xaw header files
    and libraries in the configure script.
  * [x3270] Put the dryrun script in the object directory.
  * [wc3270] Allow Windows VKey codes to be specified in wc3270
    keymaps in hexadecimal with the syntax VKEY-0xnn. This allows
    unknown VKeys to be specified. The same syntax is used in
    traces.
  * [x3270] Fixed an issue where parameters beyond the second were
    ignored in many keymap actions.
  * [all] Fixed an issue with the Abort action called from scripts.
  * [all Windows] Always find root_certs.txt in the same directory
    as the executable, if not installed.
  * [all] Validate the parameters to the Transfer() action better.
  * [pr3287] Fix the configure script so it properly detects
    missing OpenSSL header files, even if the OpenSSL library is
    present.
  * [all] Limit DFT buffer size to 32767. 32768 causes the host to
    send 0-byte buffers.
  * [x3270] Dropped support for xmkmf and imake. x3270 builds and
    installs only using autoconf paths now.
  * see http://x3270.bgp.nu/documentation-relnotes.html for more
    detailed list of changes
- Drop no longer needed pr3270-memleak.patch
- Cleanup spec file with spec-cleaner
- Make sure that optflags are used in building
* Tue Feb  9 2016 mrueckert@suse.de
- added desktop file
- split up font reconfigure macro into the pieces so we can add the
  desktop file macros too
* Wed Jan 20 2016 tchvatal@suse.com
- Version update to ga10 of 3.4 series:
  * [x3270] Fixed a crash in the Configure Idle Command pop-up.
  * [x3270] Fixed an issue with overwriting local files in file transfers.
  * [s3270] Fixed an x3270if build problem when libiconv is needed.
  * [all] Fixed a problem with truncating the list of LUs when connecting to a
    host.
  * [all] Fixed a crash when too many parameters are passed to an action in a macro
    or script.
  * [c3270, wc3270] Fixed binary file transfer bug.
  * [x3270] Fixed missing 'Not Connected' message when disconnecting from a host.
  * [all] Fixed trace display of incoming IPv6 connections and the parsing of the
    x3270 -scriptport option.
  * [tcl3270] Added tcl3270 support for Tcl 8.6.
  * [all] Renamed $INSTALL variable in the top-level configure script (bugs:15).
* Mon Sep  7 2015 tchvatal@suse.com
- Version bump to 3.4:
  * Recreated tarball and build approach so adapt our system
  * Fixed a number of warnings found by the MacOS C compiler, which turned out
    to be real issues.
  * [all] Synchronize the ReadBuffer action with the Wait(Output) action, just
    like Ascii and Ebcdic.
  * [all] Fixed an NVT-mode emulation problem.
  * [all] Fixed a synchronization issue with scripts and file transfers.
  * [c3270, wc3270] Fixed a crash when the Transfer action was called from a
    script.
  * [x3270] Fixed a crash when visible control characters are turned on in
    3278 mode.
  * [pr3287] Changed the pr3287 Makefile to use $INSTALL_DATA (bugs:#13).
  * [All Unix] Added -D_DEFAULT_SOURCE wherever a Makefile used -D_BSD_SOURCE,
    to get rid of compiler warnings with newer versions of glibc (bugs:#12).
  * [x3270, c3270, wc3270] Corrected the OIA display of save-to-printer pages.
  * [c3270, wc3270] Made the help for file-transfer reflect the current
    defaults. Added help for Keymap.
  * [wc3270] Fixed the pager at the wc3270> prompt. Now it adapts to the size
    of the console window correctly.
  * [pr3287, wpr3287] Fixed a problem with printer session start-up when both
    a specific printer LU and an SSL tunnel (L:) are specified.
  * [c3270, wc3270] Added a Keymap action to add or remove temporary keymaps.
    The semantics are the same as the x3270 action of the same name.
  * [all] Made the parameter to ResumeScript optional, and relaxed the
    restrictions on when PauseScript can be used, so it can now be used from
    macros and command files read with the Source action.
  * [c3270, wc3270] Allow the DFT buffer size to be changed in the c3270/wc3270
    file transfer dialog.
  * [c3270, wc3270] Allow file transfers to be interrupted with Ctrl-C.
  * [x3270] Fixed an issue where the terminal type would not be reported to the
    host as IBM-DYNAMIC if the screen was put into oversize mode via a menu
    selection (it was correct if oversize came from a resource). Also made sure
    that the 'About->Configuration' display of the terminal type is always
    correct.
  * [all] Added resources to define the default values for each of the IND$FILE
    file transfer parameters. The resources have the same names as the Transfer
    action keywords, with ft prepended. E.g., the Mode default is controlled by
    the ftMode resource. For consistency, deprecated dftBufferSize and
    ftCodePage in favor of ftBufferSize and ftWindowsCodePage (the old
    resources are still available).
  * [all] Added missing functionality to specify the size for avblock TSO file
    allocations in IND$FILE file transfers.
  * [x3270] Added an aplCircledAlpha resource to allow x3270 to properly
    display APL underscored uppercase letters with the APL385 font, by
    translating them to the (nonstandard) Unicode circled-alphabetic range
    U+24B6 to U+25CF.
  * [x3270, c3270, wc3270] Overhauled visible control characters so that field
    attributes are completely decoded. Field attributes are now in underlined
    yellow in x3270. Added visible control character support to c3270 (also
    underlined yellow) and wc3270 (reverse-video yellow), with a menu option.
  * [all] Overhauled the build structure. Now there are libraries for common
    functions.
  * [wc3270] Mapped Alt-left-click onto a lightpen select operation. Added a
    lightPenPrimary resource to switch this, so that an unmodified left-click
    is a lightpen select and Alt-left-click is a cursor move or copy/paste
    highlight.
  * [all] Added a B: prefix option to hostnames to disable the automatic
    keyboard unlock when a BIND-IMAGE is received.
  * [all] Added an -nvt option and an nvtMode resource to force NVT mode as
    soon as a session is connected. This overrides the usual behavior of
    locking the keyboard and waiting for the host to send NVT-mode data or
    negotiate 3270 mode before unlocking. This option also changes the default
    terminal type to xterm.
  * [c3270] Added a mapping from the Escape key to the Escape() action
    (breaking to the c3270> prompt).
  * [x3270] Added a maxRecent resource to control the maximum size of the
    recent host list in the Connect menu.
  * [all] Allow the -scriptport option to specify an address to listen on.
  * [all] Added webserver support. The -httpd option starts a webserver
    listening on the specified port. The webserver supports a REST API and
    some basic HTML objects.
  * [all] Removed configurability of tracing, NVT mode, TN3270E support,
    scripting, menus file transfer, the x3270 pop-up keypad and printer
    sessions (they're always enabled now).
  * [x3270, wc3270] Added an overlayPaste toggle. When set, pasting over a
    protected field will simply increment the cursor position instead of
    locking the keyboard. This allows forms to be copied and pasted with the
    protected fields included. Setting this toggle also implicitly sets the
    marginedPaste toggle.
  * [x3270] Changed the selection logic so that a rectangular selection
    (the default for 3270 mode) never ends with a newline character.
- Refresh patches:
  * mknod.patch
  * pr3270-memleak.patch
  * usr_local_bin.patch
- Add new patch to fix missing include:
  * x3270-missing-include.patch
- Add new patch to fix missed file from tarball, taken from older version:
  * x3270-missing-file.patch
* Sun Apr 26 2015 crrodriguez@opensuse.org
- Only BuildRequire the needed packages, not legacy
  metapackage xorg-x11-devel.
* Mon Apr 20 2015 mpluskal@suse.com
- Update to 3.3.14
  * [x3270, wc3270] Improved paste behavior. Patch courtesy of
    Máximo Castañeda.
  * [all] Added append and replace keywords to the PrintText
    action to control how existing files are handled.
  * [all] Made Wait(Output) work in NVT mode.
  * [x3270] Fixed security holes in the Print Window Bitmap menu
    item and the PrintWindow action.
  * [wc3270] Fixed multiple GDI printing problems: captions
    mis-centered, page overflow with multiple screens per page,
    "save screens to printer" not working at all.
* Wed Sep 24 2014 tchvatal@suse.com
- Version bump to 3.3.14 and update x026 to 1.2:
  * For full change list read:
    http://x3270.bgp.nu/documentation-relnotes.html
- Remove suse readme which is totally pointless
- Clean spec with spec-cleaner
- Remove unused patch gcc4.diff
* Thu Sep 18 2014 sfalken@opensuse.org
- Removed %%attr stanza from %%files section as it was causing rpmlint
  failure, and is not neccessary
- Added fdupes to BuildRequires and to %%install section to clear rpmlint
  warning about duplicate files
* Mon Aug  4 2014 jjolly@suse.com
- Renamed README.SuSE to README.SUSE to comply with file name
  policy (bnc#888998)
* Wed Jul 24 2013 tchvatal@suse.com
- Fix building with new rpm and just use the macros availiable in
  place of current hardcoded stuff. Passing of arguments to cp in
  %%doc macro seem not to be possible anymore.
* Wed Jun 12 2013 jjolly@suse.com
- New upstream release, fixes SSL verification problems (bnc#807424)
  - Changes in version 3.3.12ga13, 2. May 2013
  - [c3270, wc3270] Fixed a start-up crash when the tracing is
    enabled and the menu bar is disasbled.
  - [all] Added support for the LF (X'25') format control order.
  - [all] Fixed a number of buffer overflow crashes.
  - Changes in version 3.3.12ga12, 20. March 2013
  - [All] Added logic to verify the name in the host certificate.
  - [All] Pass all SSL-related parameters to the pr3287 session.
  - [x3270] On the *Connect* menu, made the recent host list a
    pull-right sub-menu, if there is an ibm_hosts file in use.
  - [x3270] The *-trace* option now implies event tracing as well.
  - [x3270] Spaces are now allowed in the file transfer dialog
    local file name.
  - [all] Corrected issues when invalid Unicode characters are
    encountered during a file transfer.
  - [x3270, wc3270] Corrected a crash when tracing without a file,
    when the monitor window was closed.
  - [ws3270] Corrected the behavior of stdin processing, so ws3270
    is not blocked trying to read stdin most of the time. Also
    fixed an issue where the scripting prompt would start with *E*
    when the keyboard was in inhibit mode.
  - [wc3270] Removed a duplicated rule in Msc/Makefile.
  - [all] Changed the CGCSGID for cp930 (Japanese) 0x080b012c
    (2059, 300) to 0x0172012c (370, 300).
  - [wc3270, c3270] Corrected the behavior of the Menu option in
    the Session Wizard and the *menuBar* resource, neither of
    which worked correctly.
* Thu Mar 28 2013 jjolly@suse.com
- Added BuildRequires: bdftopcf for bnc#809972
* Sun Jan 27 2013 mkoegler@auto.tuwien.ac.at
- New upstream release, fixes SSL problems
  - Changes in version 3.3.12ga11, 23. July 2012
  * [all] Corrected a problem with not sending the TELNET TERMINAL TYPE when the TELNET NEW ENVIRONMENT option had been negotiated.
  * [x3270, c3270] Corrected issues with manual page warnings.
  - Changes in version 3.3.12ga10, 8. July 2012
  * [all] Turned off SSL host cerfication and Added a verifyHostCert resource and -verifycert option to enable it.
  * [wc3270] Improved behavior when SSL negotiation fails.
  * [x3270, c3270, wc3270] Changed the 'secure' icon to green when SSL/TLS is active and the host is verified, and yellow when SSL/TLS is active but the host is unverified.
  * [c3270] Added a defaultFgBg resource and -defaultfgbg option to use the terminal's default foreground and background colors in place of the curses colors white and black respectively -- if the ncurses library, terminal and termcap/terminfo entry support default color. It is automatically set for gnome-terminal.
  - Changes in version 3.3.12beta9, 13. February 2012
  * [all] Added a selfSignedOk resource to allow SSL authentication with hosts that use self-signed certificates.
* Mon Aug  6 2012 pgajdos@suse.com
- prepare spec file for dropping SuSEconfig.fonts (openFATE#313536)
* Wed Dec 21 2011 coolo@suse.com
- add autoconf as buildrequire to avoid implicit dependency
* Mon Dec 19 2011 coolo@suse.de
- remove call to suse_update_config
* Thu Sep 15 2011 bg@suse.com
- Update to version 3.3.12ga7
  - lots of bug fixes
  - for a complete list, see http://x3270.bgp.nu/documentation-relnotes.html
- remove unneeded patches
  - tcl8.4.patch
  - gcc-322.diff
- use combined tar ball from upstream
- enable SSL feature
* Mon Nov  8 2010 coolo@novell.com
- remove support for pre-9.1
* Sun Nov 15 2009 meissner@suse.de
- refresh patches with fuzz=0
* Tue Apr  8 2008 max@suse.de
- Fixed build for Tcl 8.5.
* Thu Mar 29 2007 ro@suse.de
- added ncurses-devel to buildreq
* Wed Mar 28 2007 mfabian@suse.de
- add run_suseconfig_fonts to %%post and %%postun
* Fri Nov 10 2006 ihno@suse.de
- fixing wrong permissions of man pages
* Thu Aug 10 2006 mfabian@suse.de
- move fonts, binaries, man-pages to the new paths used by
  X11R7 (fixes build in STABLE).
- use RPM_OPT_FLAGS
* Thu Feb 16 2006 ro@suse.de
- fix directory permissions
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jun 20 2005 yxu@suse.de
- fixed patch to apply
* Thu Jun 16 2005 yxu@suse.de
- update sources to version 3.3.4
* Thu Apr 21 2005 coolo@suse.de
- fix compilation
* Tue May 11 2004 hare@suse.de
- Do not call mkfontsdir to avoid dependency problems (#40318).
* Wed Apr 28 2004 hare@suse.de
- Fix memleak in pr3270 (#39528).
* Fri Feb 27 2004 hare@suse.de
- Update to 3.3.2p1.
* Sat Jan 10 2004 adrian@suse.de
- fix to build as user
* Sun Nov  2 2003 ro@suse.de
- updated neededforbuild
* Mon Aug 11 2003 hare@suse.de
- Fixed ppc64 build problems.
- Fixed gcc-3.3 compilation warnings.
* Fri Jul 18 2003 hare@suse.de
- Added freetype2 to prerequisites.
* Thu Jun 12 2003 kukuk@suse.de
- Fix filelist
* Fri Jun  6 2003 mmj@suse.de
- Remove unwanted files from BuildRoot.
* Mon Feb 24 2003 froh@suse.de
- updated to 3.2.20 bug fix only drop which incoroprates all
  the patches we had on top of 3.2.19
* Wed Nov 27 2002 sf@suse.de
- added patch x3270-3.2.19.x86_64.diff to prevent segfaulting
  on x86_64
* Thu Sep 26 2002 ro@suse.de
- removed bogus self-provides again (3rd time)
* Thu Sep 26 2002 froh@suse.de
- during installation with YaST, mkfontdir will be called by yast
  automatically.  thus added test to %%-post* scripts to not
  run mkfontdir in case the package is installed from withing YaST.
  (#20127)
* Mon Sep 23 2002 froh@suse.de
- drop use of chroot and relative paths in %%post/%%postun (#20011)
  and replace xf86 in PreReq by name of mkfontdir binary
- fix date in README.SuSE
* Tue Aug 20 2002 ro@suse.de
- built tcl3270 without tclx
* Tue Aug 13 2002 froh@suse.de
- add pacthes for known bugs
  * R1: x3270 Not Recognizing crosshair Resource
  * R2: c3270 Goes Into Tight Loop on End-of-File
  * R3: Screen Resizing Broken (this one hit us)
  * R4: Keymap Saved as 'base'
* Sun Jul 28 2002 kukuk@suse.de
- Add xf86 again
* Sat Jul 27 2002 adrian@suse.de
- fix neededforbuld and PreRequires
* Fri Jul 12 2002 max@suse.de
- Fixed tcl3270-3.2/configure.in for tcl8.4
* Mon Jul  1 2002 froh@suse.de
- updated to current release 3.2.19
- added the state of the art IBM 026 keypunch emulator :)
* Tue Feb 19 2002 froh@suse.de
- added most recent bugfixes from x3270 site
- switched to the new simpler all-in-one-tarball
* Fri Jan 25 2002 froh@suse.de
- upgraded to current release 3.2.18 + current bugfixes
* Sun Dec  9 2001 ro@suse.de
- there is no /usr/etc allowed in fhs 2.2
* Tue Nov 20 2001 froh@suse.de
- added current patches from x3270 site:
  * fixed cut&paste if  selection is spanning several lines
  * keymap fix (C-u and C-w definitions had been hidden)
* Wed Oct 31 2001 bk@suse.de
- use mode 644 for config file /usr/etc/x3270/ibm_hosts
* Thu Oct 18 2001 bk@suse.de
- make ibm_hosts file noreplace(file format was not updated, old can be used)
* Mon Jul 30 2001 froh@suse.de
- patched /usr/local/bin to /usr/bin in a new expect script below
  s3270/Examples/* and checked that no /usr/local are left :)
* Wed Jul 25 2001 froh@suse.de
- patched away /usr/local/bin in a new shell script below
  x3270/Examples/*
* Tue Jul 24 2001 froh@suse.de
- upgraded to current release 3.2.17 + current bugfixes
* Wed Mar 28 2001 froh@suse.de
- use 'size_t' consistently instead of 'unsigned' to make pr3278 build
  on axp (use-size_t.diff)
* Wed Mar 28 2001 froh@suse.de
- upgraded to current version 3.2.16
- added c3270, tcl3270, s3270 and made them coexist with each other
  (common config file, shared helpers)
* Thu Nov 30 2000 fober@suse.de
- upgraded to current version 3.2.14
- adopted to current FHS
- introduced BuildRoot to clean up %%files-section
* Fri Oct 27 2000 fober@suse.de
- fixed calling of mkfontdir(needs chroot if no xshared in instsys) in
  %%postun as well
* Mon Oct  9 2000 bk@suse.de
- fixed calling of mkfontdir(needs chroot if no xshared in instsys) in
  %%postin
* Wed Jun  7 2000 ro@suse.de
- fixed path for mkfontdir
* Tue Feb  1 2000 mkraft@suse.de
- updated to new (alpha) version 3.2, some changes to spec file
  - pre- and postinstall scripts to rebuild fonts.dir
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Wed Mar 17 1999 ro@suse.de
- remove .orig with -f
* Sat Sep 19 1998 ro@suse.de
- dont redeclare sys_errlist for glibc
* Thu Jul 23 1998 werner@suse.de
- Check exit status of mknod in peer_script.(ba)sh
* Mon Nov 17 1997 ro@suse.de
- changes /usr/local/bin/expect to /usr/bin/expect
  and /bin/ksh to /usr/bin/ksh
* Mon Oct 13 1997 hf@suse.de
- ready for autobuild
* Fri Jun  6 1997 bs@suse.de
- removed usr/X11R6/lib/X11/fonts/misc/fonts.dir
* Mon Jun  2 1997 hf@suse.de
  Added the x3270 app-defaults file.
* Wed May 21 1997 hf@suse.de
  A new version 3.1.1.6
  x3270 is an IBM 3278/3279 terminal emulator for X windows.
